pub struct CookieMiddleware {
pub store: Arc<RwLock<CookieStore>>,
}Expand description
Shared cookie jar middleware. Middleware that keeps a shared cookie store across requests.
Fields
store: Arc<RwLock<CookieStore>>Implementations
Sourceimpl CookieMiddleware
impl CookieMiddleware
Sourcepub fn new() -> CookieMiddleware
pub fn new() -> CookieMiddleware
Creates a new CookieMiddleware with a shared CookieStore.
Sourcepub fn with_store(store: CookieStore) -> CookieMiddleware
pub fn with_store(store: CookieStore) -> CookieMiddleware
Creates a new CookieMiddleware with a pre-populated CookieStore.
Sourcepub async fn from_json<P>(path: P) -> Result<CookieMiddleware, SpiderError>
pub async fn from_json<P>(path: P) -> Result<CookieMiddleware, SpiderError>
Load cookies from a JSON file, replacing all cookies in the store.
The JSON format is the one used by the cookie_store crate.
Sourcepub async fn from_netscape_file<P>(
path: P,
) -> Result<CookieMiddleware, SpiderError>
pub async fn from_netscape_file<P>( path: P, ) -> Result<CookieMiddleware, SpiderError>
Load cookies from a Netscape cookie file. This will add to, not replace, the existing cookies in the store.
Sourcepub async fn from_rfc6265<P>(path: P) -> Result<CookieMiddleware, SpiderError>
pub async fn from_rfc6265<P>(path: P) -> Result<CookieMiddleware, SpiderError>
Load cookies from a file where each line is a Set-Cookie header value.
The Domain attribute must be explicitly set in each cookie line.