pub struct CsvPipeline<I> { /* private fields */ }Expand description
CSV file output pipeline. A pipeline that exports scraped items to a CSV file. Headers are determined from the keys of the first item processed.
Implementations
Sourceimpl<I> CsvPipeline<I>where
I: ScrapedItem,
impl<I> CsvPipeline<I>where
I: ScrapedItem,
Sourcepub fn new(file_path: impl AsRef<Path>) -> Result<CsvPipeline<I>, PipelineError>
pub fn new(file_path: impl AsRef<Path>) -> Result<CsvPipeline<I>, PipelineError>
Sourcepub fn with_schema_export_config(
self,
config: SchemaExportConfig,
) -> CsvPipeline<I>
pub fn with_schema_export_config( self, config: SchemaExportConfig, ) -> CsvPipeline<I>
Applies typed export mapping before values are written.