pub struct DeduplicationPipeline<I>where
I: ScrapedItem,{ /* private fields */ }Expand description
Built-in pipelines that do not require extra feature flags. Pipeline that filters duplicate items based on a configurable field set.
Implementations
Sourceimpl<I> DeduplicationPipeline<I>where
I: ScrapedItem,
impl<I> DeduplicationPipeline<I>where
I: ScrapedItem,
Sourcepub fn new<F, S>(unique_fields: F) -> DeduplicationPipeline<I>
pub fn new<F, S>(unique_fields: F) -> DeduplicationPipeline<I>
Creates a new DeduplicationPipeline with a specified set of unique fields.