pub struct JsonPipeline<I>where
I: ScrapedItem,{ /* private fields */ }Expand description
JSON array output pipeline. A pipeline that writes all scraped items to a single JSON file as a JSON array. Items are collected in a blocking task and written to disk when the pipeline is closed.
Implementations
Sourceimpl<I> JsonPipeline<I>where
I: ScrapedItem,
impl<I> JsonPipeline<I>where
I: ScrapedItem,
Sourcepub fn new(
file_path: impl AsRef<Path>,
) -> Result<JsonPipeline<I>, PipelineError>
pub fn new( file_path: impl AsRef<Path>, ) -> Result<JsonPipeline<I>, PipelineError>
Sourcepub fn with_schema_export_config(
self,
config: SchemaExportConfig,
) -> JsonPipeline<I>
pub fn with_schema_export_config( self, config: SchemaExportConfig, ) -> JsonPipeline<I>
Applies typed export mapping before values are written.