pub struct SqlitePipeline<I>where
I: ScrapedItem,{ /* private fields */ }Expand description
SQLite output pipeline. A pipeline that writes scraped items to a SQLite database. All database operations are offloaded to a dedicated blocking thread.
Implementations
Sourceimpl<I> SqlitePipeline<I>where
I: ScrapedItem,
impl<I> SqlitePipeline<I>where
I: ScrapedItem,
Sourcepub fn new(
db_path: impl AsRef<Path>,
table_name: impl Into<String>,
) -> Result<SqlitePipeline<I>, PipelineError>
pub fn new( db_path: impl AsRef<Path>, table_name: impl Into<String>, ) -> Result<SqlitePipeline<I>, PipelineError>
Creates a new SqlitePipeline that writes items to the specified database path and table.
Sourcepub fn with_schema_export_config(
self,
config: SchemaExportConfig,
) -> SqlitePipeline<I>
pub fn with_schema_export_config( self, config: SchemaExportConfig, ) -> SqlitePipeline<I>
Applies typed export mapping before rows are written.