pub struct StreamJsonPipeline<I>where
I: ScrapedItem,{ /* private fields */ }Expand description
Streaming JSON output pipeline. A pipeline that streams items directly to a JSON file without accumulating them in memory.
Implementations
Sourceimpl<I> StreamJsonPipeline<I>where
I: ScrapedItem,
impl<I> StreamJsonPipeline<I>where
I: ScrapedItem,
Sourcepub fn new(
file_path: impl AsRef<Path>,
) -> Result<StreamJsonPipeline<I>, PipelineError>
pub fn new( file_path: impl AsRef<Path>, ) -> Result<StreamJsonPipeline<I>, PipelineError>
Creates a new StreamJsonPipeline with default batch size.
Errors
Returns an error when the output directory cannot be created.
Sourcepub fn with_batch_size(
file_path: impl AsRef<Path>,
batch_size: usize,
) -> Result<StreamJsonPipeline<I>, PipelineError>
pub fn with_batch_size( file_path: impl AsRef<Path>, batch_size: usize, ) -> Result<StreamJsonPipeline<I>, PipelineError>
Creates a new StreamJsonPipeline with a specified batch size.
Errors
Returns an error when the output directory cannot be created.
Sourcepub fn with_schema_export_config(
self,
config: SchemaExportConfig,
) -> StreamJsonPipeline<I>
pub fn with_schema_export_config( self, config: SchemaExportConfig, ) -> StreamJsonPipeline<I>
Applies typed export mapping before values are written.