Struct VisitedUrls
pub struct VisitedUrls { /* private fields */ }Expand description
Core runtime types and traits used to define and run a crawl. A thread-safe URL tracker using DashMap.
This provides efficient concurrent access for tracking visited URLs without requiring explicit locks.
Example
ⓘ
use spider_core::state::VisitedUrls;
let visited = VisitedUrls::new();
visited.mark("https://example.com".to_string());
assert!(visited.is_visited("https://example.com"));Implementations
impl VisitedUrls
impl VisitedUrls
pub fn new() -> VisitedUrls
pub fn new() -> VisitedUrls
Creates a new empty URL tracker.
pub fn with_capacity(capacity: usize) -> VisitedUrls
pub fn with_capacity(capacity: usize) -> VisitedUrls
Creates a URL tracker with the specified capacity.
pub fn is_visited(&self, url: &str) -> bool
pub fn is_visited(&self, url: &str) -> bool
Checks if a URL has been visited.
pub fn clear(&self)
pub fn clear(&self)
Clears all visited URLs.