pub fn create_dir(dir_path: impl AsRef<Path>) -> Result<(), SpiderError>Expand description
Shared runtime data types and convenience helpers. Creates a directory and all of its parent components if they are missing.
Errors
Returns an error if the directory cannot be created.