pub struct JsonlPipeline<I>where
I: ScrapedItem,{ /* private fields */ }Expand description
JSON Lines output pipeline. A pipeline that writes each scraped item to a JSON Lines (.jsonl) file. Each item is written as a JSON object on a new line.
Implementations
Sourceimpl<I> JsonlPipeline<I>where
I: ScrapedItem,
impl<I> JsonlPipeline<I>where
I: ScrapedItem,
Sourcepub fn new(
file_path: impl AsRef<Path>,
) -> Result<JsonlPipeline<I>, PipelineError>
pub fn new( file_path: impl AsRef<Path>, ) -> Result<JsonlPipeline<I>, PipelineError>
Creates a new JsonlPipeline that writes to the specified file path.
Errors
Returns an error when the output file cannot be opened or the parent directory cannot be created.
Sourcepub fn with_schema_export_config(
self,
config: SchemaExportConfig,
) -> JsonlPipeline<I>
pub fn with_schema_export_config( self, config: SchemaExportConfig, ) -> JsonlPipeline<I>
Applies typed export mapping before values are written.